@@ -7,9 +7,9 @@ use warnings;
 
 use Carp;
 
-use base qw{ Exporter };
+use Exporter qw{ import };
 
-our $VERSION = '0.099_002';
+our $VERSION = '0.100_01';
 
 our @EXPORT_OK = qw{
     meta_merge
@@ -44,7 +44,7 @@ sub meta_merge {
 	resources	=> {
 	    bugtracker	=> {
                 web => 'https://rt.cpan.org/Public/Dist/Display.html?Name=Perl-Critic-Policy-Variables-ProhibitUnusedVarsStricter',
-                mailto  => 'wyant@cpan.org',
+##                mailto  => 'wyant@cpan.org',
             },
 	    license	=> 'http://dev.perl.org/licenses/',
 	    repository	=> {
@@ -67,7 +67,7 @@ sub required_module_versions {
         'Perl::Critic::Policy'      => 1.119,
         'Perl::Critic::Utils'       => 1.119,
         'PPI::Token::Symbol'        => 0,
-        'PPIx::QuoteLike'           => 0.004,   # For old Perls
+        'PPIx::QuoteLike'           => 0.005,
         'Readonly'                  => 0,
         'Scalar::Util'              => 0,
         @args,
@@ -156,7 +156,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013-2016 by Thomas R. Wyant, III
+Copyright (C) 2013-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
